# proyecto de modulos 

## Este trabajo trata sobre la creacion de un paquete_modulo y subirlo a python 

### uso del programa:
'''Python

from jhanelsollesgarcia import cal


print(cal.area_cir(5))
'''